@@ -46,7 +46,7 @@ _DictOrPydantic = Union[dict, _BM]
 
 
 class _ModelProviderConfigType(BaseModel):
-    supported_tool_choice: ToolChoiceType = Field(default=[])
+    supported_tool_choice: ToolChoiceType = Field(default_factory=list)
     keep_reasoning_content: bool = Field(default=False)
     support_json_mode: bool = Field(default=False)
 
@@ -126,12 +126,15 @@ class _BaseChatOpenAICompatible(BaseChatOpenAI):
         stop: list[str] | None = None,
         **kwargs: Any,
     ) -> dict:
+        payload = {**self._default_params, **kwargs}
+
+        if self._use_responses_api(payload):
+            return super()._get_request_payload(input_, stop=stop, **kwargs)
+
         messages = self._convert_input(input_).to_messages()
         if stop is not None:
             kwargs["stop"] = stop
 
-        payload = {**self._default_params, **kwargs}
-
         payload_messages = []
 
         for m in messages:
